package de.ullisroboterseite.crc;

// https://docs.oracle.com/javase/8/docs/api/java/util/zip/CRC32.html

public class JavaCCRGeneratorTest {
        static final byte[] testData = new byte[] { //
                        (byte) 0x31, (byte) 0x32, (byte) 0x33, (byte) 0x34, (byte) 0x35, (byte) 0x36, (byte) 0x37,
                        (byte) 0x38, (byte) 0x39
        }; // "123456789"
        static final byte[] testData1 = new byte[] { //
                        (byte) 0xE4, (byte) 0x6D, (byte) 0x46, (byte) 0xF8, (byte) 0xFB, (byte) 0x16, (byte) 0xAB,
                        (byte) 0x52,
                        (byte) 0xED, (byte) 0x64, (byte) 0x50, (byte) 0x23, (byte) 0x63, (byte) 0x0D, (byte) 0x80,
                        (byte) 0xBC,
                        (byte) 0x98, (byte) 0xD8, (byte) 0x16, (byte) 0xFF, (byte) 0xEF, (byte) 0x3C, (byte) 0x4E,
                        (byte) 0xD9,
                        (byte) 0xBD, (byte) 0xA1, (byte) 0x85, (byte) 0x95, (byte) 0x13
        };
        static final byte[] testData2 = new byte[] { //
                        (byte) 0x42, (byte) 0xDF, (byte) 0x54, (byte) 0x99, (byte) 0x99, (byte) 0x20, (byte) 0x98,
                        (byte) 0xCF,
                        (byte) 0xF1, (byte) 0xFC, (byte) 0xF5, (byte) 0x9E, (byte) 0xED, (byte) 0x36, (byte) 0x61,
                        (byte) 0x4A,
                        (byte) 0xA2, (byte) 0x31, (byte) 0xF3, (byte) 0x3E, (byte) 0x02, (byte) 0xB1, (byte) 0x8A,
                        (byte) 0x95,
                        (byte) 0xE5, (byte) 0xF7, (byte) 0x88
        };
        static final byte[] testData3 = new byte[] { //
                        (byte) 0x5B, (byte) 0xB5, (byte) 0x06, (byte) 0x04, (byte) 0x52, (byte) 0xDE, (byte) 0xD8,
                        (byte) 0xEC,
                        (byte) 0x13, (byte) 0x35, (byte) 0x6B, (byte) 0x59, (byte) 0xC8, (byte) 0x66, (byte) 0xA4,
                        (byte) 0xF6,
                        (byte) 0xC9, (byte) 0xA8, (byte) 0x63, (byte) 0x03, (byte) 0xB9,
                        (byte) 0xA8, (byte) 0xFD, (byte) 0xD9, (byte) 0x57
        };

        static final CRC8GeneratorLookUp crc8Generator = new CRC8GeneratorLookUp();
        static final CRC16GeneratorLookUp crc16Generator = new CRC16GeneratorLookUp();
        static final CRC32Generator crc32Generator = new CRC32Generator();

        static int stream8TestData(byte[] data) {
                for (int i = 0; i < data.length; i++)
                        crc8Generator.streamCRC(data[i]);
                return crc8Generator.streamFin();
        }

        static int stream16TestData(byte[] data) {
                for (int i = 0; i < data.length; i++)
                        crc16Generator.streamCRC(data[i]);
                return crc16Generator.streamFin();
        }

        static long stream32TestData(byte[] data) {
                for (int i = 0; i < data.length; i++)
                        crc32Generator.streamCRC(data[i]);
                return crc32Generator.streamFin();
        }

        public static void main(String[] args) {

                System.out.println("Java CRC-Generator Test");

                System.out.println("==========================\n");
                System.out.println("  CRC8");
                System.out.println("==========================");

                System.out.println("  genCRC: " + crc8Generator.generateCRC(testData));
                System.out.println("  stream: " + stream8TestData(testData));
                System.out.println("--------------------------");
                System.out.println("1 genCRC: " + crc8Generator.generateCRC(testData1));
                System.out.println("  stream: " + stream8TestData(testData1));
                System.out.println("--------------------------");
                System.out.println("2 genCRC: " + crc8Generator.generateCRC(testData2));
                System.out.println("  stream: " + stream8TestData(testData2));
                System.out.println("--------------------------");
                System.out.println("3 genCRC: " + crc8Generator.generateCRC(testData3));
                System.out.println("  stream: " + stream8TestData(testData3));

                System.out.println("==========================\n");
                System.out.println("  CRC16");
                System.out.println("==========================");

                System.out.println("  genCRC: " + crc16Generator.generateCRC(testData));
                System.out.println("  stream: " + stream16TestData(testData));
                System.out.println("--------------------------");
                System.out.println("1 genCRC: " + crc16Generator.generateCRC(testData1));
                System.out.println("  stream: " + stream16TestData(testData1));
                System.out.println("--------------------------");
                System.out.println("2 genCRC: " + crc16Generator.generateCRC(testData2));
                System.out.println("  stream: " + stream16TestData(testData2));
                System.out.println("--------------------------");
                System.out.println("3 genCRC: " + crc16Generator.generateCRC(testData3));
                System.out.println("  stream: " + stream16TestData(testData3));

                System.out.println("==========================\n");
                System.out.println("  CRC32");
                System.out.println("==========================");

                System.out.println("  genCRC: " + crc32Generator.generateCRC(testData));
                System.out.println("  stream: " + stream32TestData(testData));
                System.out.println("--------------------------");
                System.out.println("1 genCRC: " + crc32Generator.generateCRC(testData1));
                System.out.println("  stream: " + stream32TestData(testData1));
                System.out.println("--------------------------");
                System.out.println("2 genCRC: " + crc32Generator.generateCRC(testData2));
                System.out.println("  stream: " + stream32TestData(testData2));
                System.out.println("--------------------------");
                System.out.println("3 genCRC: " + crc32Generator.generateCRC(testData3));
                System.out.println("  stream: " + stream32TestData(testData3));
        }
}
/* Output:

Java CRC-Generator Test
==========================

  CRC8
==========================
  genCRC: 244
  stream: 244
--------------------------
1 genCRC: 133
  stream: 133
--------------------------
2 genCRC: 233
  stream: 233
--------------------------
3 genCRC: 229
  stream: 229
==========================

  CRC16
==========================
  genCRC: 58828
  stream: 58828
--------------------------
1 genCRC: 39760
  stream: 39760
--------------------------
2 genCRC: 59077
  stream: 59077
--------------------------
3 genCRC: 32278
  stream: 32278
==========================

  CRC32
==========================
  genCRC: 3421780262
  stream: 3421780262
--------------------------
1 genCRC: 1628163719
  stream: 1628163719
--------------------------
2 genCRC: 2942970280
  stream: 2942970280
--------------------------
3 genCRC: 948803831
  stream: 948803831

*/